@@ -33,7 +33,7 @@ void init_idna(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto result = IDNA::createUTS46Instance(options, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
@@ -44,7 +44,7 @@ void init_idna(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.labelToASCII(label, dest, info, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -56,7 +56,7 @@ void init_idna(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.labelToASCII(label, dest, info, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -67,7 +67,7 @@ void init_idna(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.labelToUnicode(label, dest, info, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -79,7 +79,7 @@ void init_idna(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.labelToUnicode(label, dest, info, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -90,7 +90,7 @@ void init_idna(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.nameToASCII(name, dest, info, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -102,7 +102,7 @@ void init_idna(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.nameToASCII(name, dest, info, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -113,7 +113,7 @@ void init_idna(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.nameToUnicode(name, dest, info, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
@@ -125,7 +125,7 @@ void init_idna(py::module &m) {
             UErrorCode error_code = U_ZERO_ERROR;
             auto &result = self.nameToUnicode(name, dest, info, error_code);
             if (U_FAILURE(error_code)) {
-              throw ICUException(error_code);
+              throw ICUError(error_code);
             }
             return result;
           },
