@@ -74,6 +74,7 @@ void init_tznames(py::module &m);
 void init_tzrule(py::module &m);
 void init_tztrans(py::module &m);
 void init_ubidi(py::module &m);
+void init_ubiditransform(py::module &m);
 void init_ubrk(py::module &m);
 void init_ucal(py::module &m);
 void init_uchar(py::module &m);
@@ -105,8 +106,13 @@ void init_ures(py::module &m);
 void init_uscript(py::module &m);
 void init_usearch(py::module &m);
 void init_uset(py::module &m);
+void init_usetiter(py::module &m);
+void init_ushape(py::module &m);
+void init_uspoof(py::module &m);
+void init_usprep(py::module &m);
 void init_ustring(py::module &m);
 void init_utext(py::module &m);
+void init_utmscale(py::module &m);
 void init_utrans(py::module &m);
 void init_utypes(py::module &m);
 void init_uversion(py::module &m);
@@ -241,6 +247,7 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_sortkey(m);       // icu::CollationKey
 
   init_uniset(m);      // icu::UnicodeSet
+  init_usetiter(m);    // icu::UnicodeSetIterator
   init_normalizer2(m); // icu::Normalizer2, icu::FilteredNormalizer2
   init_tblcoll(m);     // icu::RuleBasedCollator
   init_stsearch(m);    // icu::StringSearch
@@ -251,6 +258,7 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_unistr(m, rep, us); // icu::UnicodeString
 
   init_ubidi(m);
+  init_ubiditransform(m);
   init_ubrk(m);
   init_ucal(m);
   init_uchar(m);
@@ -280,8 +288,12 @@ PYBIND11_MODULE(MODULE_NAME, m) {
   init_uscript(m);
   init_usearch(m);
   init_uset(m);
+  init_ushape(m);
+  init_uspoof(m);
+  init_usprep(m);
   init_ustring(m);
   init_utext(m);
+  init_utmscale(m);
   init_utrans(m);
   init_utypes(m);
   init_uversion(m);
