@@ -22,7 +22,7 @@ void init_sortkey(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         auto result = self.compareTo(target, error_code);
         if (U_FAILURE(error_code)) {
-          throw ICUException(error_code);
+          throw ICUError(error_code);
         }
         return result;
       },
