@@ -65,11 +65,52 @@ void init_timezone(py::module &m) {
     }
     return tz;
   });
+#if (U_ICU_VERSION_MAJOR_NUM >= 70)
+  tz.def_static("create_enumeration", []() {
+    UErrorCode error_code = U_ZERO_ERROR;
+    auto result = TimeZone::createEnumeration(error_code);
+    if (U_FAILURE(error_code)) {
+      throw ICUError(error_code);
+    }
+    return result;
+  });
+#ifndef U_HIDE_DEPRECATED_API
+  tz.def_static("create_enumeration", py::overload_cast<const char *>(&TimeZone::createEnumeration), py::arg("country"))
+      .def_static("create_enumeration", py::overload_cast<int32_t>(&TimeZone::createEnumeration),
+                  py::arg("raw_offset"));
+#endif // U_HIDE_DEPRECATED_API
+#else  // !(U_ICU_VERSION_MAJOR_NUM >= 70)
   tz.def_static("create_enumeration", py::overload_cast<>(&TimeZone::createEnumeration))
       .def_static("create_enumeration", py::overload_cast<const char *>(&TimeZone::createEnumeration),
                   py::arg("country"))
       .def_static("create_enumeration", py::overload_cast<int32_t>(&TimeZone::createEnumeration),
                   py::arg("raw_offset"));
+#endif // !(U_ICU_VERSION_MAJOR_NUM >= 70)
+
+#if (U_ICU_VERSION_MAJOR_NUM >= 70)
+  tz.def_static(
+      "create_enumeration_for_raw_offset",
+      [](int32_t raw_offset) {
+        UErrorCode error_code = U_ZERO_ERROR;
+        auto result = TimeZone::createEnumerationForRawOffset(raw_offset, error_code);
+        if (U_FAILURE(error_code)) {
+          throw ICUError(error_code);
+        }
+        return result;
+      },
+      py::arg("raw_offset"));
+  tz.def_static(
+      "create_enumeration_for_region",
+      [](const char *region) {
+        UErrorCode error_code = U_ZERO_ERROR;
+        auto result = TimeZone::createEnumerationForRegion(region, error_code);
+        if (U_FAILURE(error_code)) {
+          throw ICUError(error_code);
+        }
+        return result;
+      },
+      py::arg("region"));
+#endif // (U_ICU_VERSION_MAJOR_NUM >= 70)
   tz.def_static(
         "create_time_zone",
         [](const UnicodeString &id) -> std::variant<BasicTimeZone *, TimeZone *> {
@@ -215,7 +256,7 @@ void init_timezone(py::module &m) {
         [](const UnicodeString &id) {
           UErrorCode error_code = U_ZERO_ERROR;
           std::string result(8, '\0');
-          auto length = TimeZone::getRegion(id, result.data(), (int32_t)result.size(), error_code);
+          auto length = TimeZone::getRegion(id, result.data(), static_cast<int32_t>(result.size()), error_code);
           if (U_FAILURE(error_code)) {
             throw ICUError(error_code);
           }
@@ -229,7 +270,7 @@ void init_timezone(py::module &m) {
           [](const char16_t *id) {
             UErrorCode error_code = U_ZERO_ERROR;
             std::string result(8, '\0');
-            auto length = TimeZone::getRegion(id, result.data(), (int32_t)result.size(), error_code);
+            auto length = TimeZone::getRegion(id, result.data(), static_cast<int32_t>(result.size()), error_code);
             if (U_FAILURE(error_code)) {
               throw ICUError(error_code);
             }
@@ -333,7 +374,7 @@ void init_timezone(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         const InitialTimeZoneRule *initial;
         std::vector<const TimeZoneRule *> trsrules(self.countTransitionRules(error_code));
-        int32_t trscount = (int32_t)trsrules.size();
+        int32_t trscount = static_cast<int32_t>(trsrules.size());
         self.getTimeZoneRules(initial, trsrules.data(), trscount, error_code);
         if (U_FAILURE(error_code)) {
           throw ICUError(error_code);
@@ -457,7 +498,7 @@ void init_timezone(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         const InitialTimeZoneRule *initial;
         std::vector<const TimeZoneRule *> trsrules(self.countTransitionRules(error_code));
-        int32_t trscount = (int32_t)trsrules.size();
+        int32_t trscount = static_cast<int32_t>(trsrules.size());
         self.getTimeZoneRules(initial, trsrules.data(), trscount, error_code);
         if (U_FAILURE(error_code)) {
           throw ICUError(error_code);
@@ -685,7 +726,7 @@ void init_timezone(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         const InitialTimeZoneRule *initial;
         std::vector<const TimeZoneRule *> trsrules(self.countTransitionRules(error_code));
-        int32_t trscount = (int32_t)trsrules.size();
+        int32_t trscount = static_cast<int32_t>(trsrules.size());
         self.getTimeZoneRules(initial, trsrules.data(), trscount, error_code);
         if (U_FAILURE(error_code)) {
           throw ICUError(error_code);
@@ -976,7 +1017,7 @@ void init_timezone(py::module &m) {
         UErrorCode error_code = U_ZERO_ERROR;
         const InitialTimeZoneRule *initial;
         std::vector<const TimeZoneRule *> trsrules(self.countTransitionRules(error_code));
-        int32_t trscount = (int32_t)trsrules.size();
+        int32_t trscount = static_cast<int32_t>(trsrules.size());
         self.getTimeZoneRules(initial, trsrules.data(), trscount, error_code);
         if (U_FAILURE(error_code)) {
           throw ICUError(error_code);
