@@ -227,6 +227,13 @@ void init_uscript(py::module &m) {
       .value("USCRIPT_KHITAN_SMALL_SCRIPT", USCRIPT_KHITAN_SMALL_SCRIPT)
       .value("USCRIPT_YEZIDI", USCRIPT_YEZIDI)
 #endif // (U_ICU_VERSION_MAJOR_NUM >= 66)
+#if (U_ICU_VERSION_MAJOR_NUM >= 70)
+      .value("USCRIPT_CYPRO_MINOAN", USCRIPT_CYPRO_MINOAN)
+      .value("USCRIPT_OLD_UYGHUR", USCRIPT_OLD_UYGHUR)
+      .value("USCRIPT_TANGSA", USCRIPT_TANGSA)
+      .value("USCRIPT_TOTO", USCRIPT_TOTO)
+      .value("USCRIPT_VITHKUQI", USCRIPT_VITHKUQI)
+#endif // (U_ICU_VERSION_MAJOR_NUM >= 70)
 #ifndef U_HIDE_DEPRECATED_API
       .value("USCRIPT_CODE_LIMIT", USCRIPT_CODE_LIMIT)
 #endif // U_HIDE_DEPRECATED_API
@@ -253,7 +260,7 @@ void init_uscript(py::module &m) {
         const auto length = uscript_getCode(name_or_abbr_or_locale, nullptr, 0, &error_code);
         std::vector<UScriptCode> result(length);
         error_code = U_ZERO_ERROR;
-        uscript_getCode(name_or_abbr_or_locale, result.data(), (int32_t)result.size(), &error_code);
+        uscript_getCode(name_or_abbr_or_locale, result.data(), static_cast<int32_t>(result.size()), &error_code);
         if (U_FAILURE(error_code)) {
           throw ICUError(error_code);
         }
@@ -269,7 +276,7 @@ void init_uscript(py::module &m) {
         const auto length = uscript_getSampleString(script, nullptr, 0, &error_code);
         std::u16string result(length, u'\0');
         error_code = U_ZERO_ERROR;
-        uscript_getSampleString(script, result.data(), (int32_t)result.size(), &error_code);
+        uscript_getSampleString(script, result.data(), static_cast<int32_t>(result.size()), &error_code);
         if (U_FAILURE(error_code)) {
           throw ICUError(error_code);
         }
@@ -297,7 +304,7 @@ void init_uscript(py::module &m) {
         const auto length = uscript_getScriptExtensions(c, nullptr, 0, &error_code);
         std::vector<UScriptCode> result(length);
         error_code = U_ZERO_ERROR;
-        uscript_getScriptExtensions(c, result.data(), (int32_t)result.size(), &error_code);
+        uscript_getScriptExtensions(c, result.data(), static_cast<int32_t>(result.size()), &error_code);
         if (U_FAILURE(error_code)) {
           throw ICUError(error_code);
         }
