@@ -26,9 +26,9 @@ void init_uset(py::module &m) {
 
   py::class_<USerializedSet>(m, "USerializedSet").def(py::init<>());
 
-  m.attr("USET_IGNORE_SPACE") = (int32_t)USET_IGNORE_SPACE;
-  m.attr("USET_CASE_INSENSITIVE") = (int32_t)USET_CASE_INSENSITIVE;
-  m.attr("USET_ADD_CASE_MAPPINGS") = (int32_t)USET_ADD_CASE_MAPPINGS;
+  m.attr("USET_IGNORE_SPACE") = int32_t{USET_IGNORE_SPACE};
+  m.attr("USET_CASE_INSENSITIVE") = int32_t{USET_CASE_INSENSITIVE};
+  m.attr("USET_ADD_CASE_MAPPINGS") = int32_t{USET_ADD_CASE_MAPPINGS};
 
-  m.attr("USET_SERIALIZED_STATIC_ARRAY_CAPACITY") = (int32_t)USET_SERIALIZED_STATIC_ARRAY_CAPACITY;
+  m.attr("USET_SERIALIZED_STATIC_ARRAY_CAPACITY") = int32_t{USET_SERIALIZED_STATIC_ARRAY_CAPACITY};
 }
